classdef EBB
    %all properties of system
    %   being computed here ...
    
    properties
        a
        %
        E
        b
        h
        q
        %
        I
        EI
        %
        w_ref % reference dispalcement
        p_ref % reference angle
        M_ref % reference moment
        Q_ref % reference force
        %
        x
    end
    
    methods
        function obj = EBB(data)
            %initialize
            %   class
            SIunits = containers.Map;
            SIunits('m')     = 1;
            SIunits('cm')    = 1E-2;
            SIunits('mm')    = 1E-3;
            SIunits('N/m')   = 1;
            SIunits('N/m^2') = 1;
            
            obj.a    = data({'a'   },:).number*SIunits(data({'a'   },:).unit{1});
            obj.E    = data({'E'   },:).number*SIunits(data({'E'   },:).unit{1});
            obj.b    = data({'b'   },:).number*SIunits(data({'b'   },:).unit{1});
            obj.h    = data({'h'   },:).number*SIunits(data({'h'   },:).unit{1});
            obj.q    = data({'q[0]'},:).number*SIunits(data({'q[0]'},:).unit{1});
            
            % derived properties
            obj.I    = obj.b*obj.h^3/12;
            obj.EI   = obj.E*obj.I;
            % reference-values
            obj.w_ref=obj.q*obj.a^4/8/obj.EI;
            obj.p_ref=obj.q*obj.a^3/6/obj.EI;
            obj.M_ref=obj.q*obj.a^2/2;
            obj.Q_ref=obj.q*obj.a;
            
        end
        
        function A = sysmat(obj)
            %populate
            %   system matrix A

            % create matrix
            A   = zeros(8,8);
            % populate matrix (only non-zero elements)
            A( 1 , 1 ) =  1;
            A( 2 , 2 ) =  1; 
            A( 3 , 1 ) =  1;
            A( 3 , 2 ) =  2*obj.a; 
            A( 3 , 3 ) =  2*obj.a^2; 
            A( 3 , 4 ) =  (4*obj.a^3)/3; 
            A( 4 , 2 ) =  1; 
            A( 4 , 3 ) =  2*obj.a; 
            A( 4 , 4 ) =  2*obj.a^2; 
            A( 4 , 6 ) =  -1; 
            A( 5 , 3 ) =  -1; 
            A( 5 , 4 ) =  -(2*obj.a); 
            A( 5 , 7 ) =  1; 
            A( 6 , 5 ) =  1; 
            A( 7 , 7 ) =  -1; 
            A( 7 , 8 ) =  -obj.a; 
            A( 8 , 8 ) =  -1; 
        end
                
        function b = rhs(obj)
            %populate
            %   right-hand side

            % cretae matrix
            b   = zeros(8,1);
            % populate matrix
            b(7,1) = obj.q*obj.a^2/2;
            b(8,1) = obj.q*obj.a;
        end
                
    end
end

